@@ -13,15 +13,21 @@ tidy_docs <- unnest_tokens(
 tidy_docs$count <- 1
 
 triplet_dtm <- cast_dtm(tidy_docs,
-  document = "APPLICATION_ID",
-  term = "word",
-  value = "count"
+                        document = "APPLICATION_ID",
+                        term = "word",
+                        value = "count"
 )
 
 q_dfm <- cast_dfm(tidy_docs,
-  document = "APPLICATION_ID",
-  term = "word",
-  value = "count"
+                  document = "APPLICATION_ID",
+                  term = "word",
+                  value = "count"
+)
+
+sparse_mat <- cast_sparse(tidy_docs,
+                       row = "APPLICATION_ID",
+                       column = "word",
+                       value = "count"
 )
 
 mat <- as.matrix(q_dfm)
@@ -35,62 +41,75 @@ names(vec_nonames) <- NULL
 ### tests for convert_dtm ----
 
 test_that("convert_dtm can handle various inputs", {
-
+  
   # simple triplet
   d <- convert_dtm(triplet_dtm)
-
+  
   expect_true(inherits(d, "dgCMatrix"))
-
+  
   expect_equal(nrow(d), triplet_dtm$nrow)
-
+  
   expect_equal(ncol(d), triplet_dtm$ncol)
-
+  
   expect_equivalent(colnames(d), triplet_dtm$dimnames$Terms)
-
+  
   expect_equivalent(rownames(d), triplet_dtm$dimnames$Docs)
-
-
+  
+  
   # dfm
   d <- convert_dtm(q_dfm)
-
+  
   expect_true(inherits(d, "dgCMatrix"))
-
+  
   expect_equal(nrow(d), nrow(q_dfm))
-
+  
   expect_equal(ncol(d), ncol(q_dfm))
-
+  
   expect_equivalent(colnames(d), colnames(q_dfm))
-
+  
   expect_equivalent(rownames(d), rownames(q_dfm))
-
-
+  
+  
   # dense matrix
   d <- convert_dtm(mat)
-
+  
   expect_true(inherits(d, "dgCMatrix"))
-
+  
   expect_equal(nrow(d), nrow(mat))
-
+  
   expect_equal(ncol(d), ncol(mat))
-
+  
   expect_equivalent(colnames(d), colnames(mat))
-
+  
   expect_equivalent(rownames(d), rownames(mat))
-
+  
+  # sparse matrix from Matrix library
+  d <- convert_dtm(sparse_mat)
+  
+  expect_true(inherits(d, "dgCMatrix"))
+  
+  expect_equal(nrow(d), nrow(mat))
+  
+  expect_equal(ncol(d), ncol(mat))
+  
+  expect_equivalent(colnames(d), colnames(mat))
+  
+  expect_equivalent(rownames(d), rownames(mat))
+  
   # vector with names
   d <- convert_dtm(vec)
-
+  
   expect_true(inherits(d, "dgCMatrix"))
-
+  
   expect_equal(nrow(d), 1)
-
+  
   expect_equal(ncol(d), length(vec))
-
+  
   expect_equivalent(colnames(d), names(vec))
-
+  
   # vector without names
   expect_error(convert_dtm(vec_nonames))
-
+  
   # not a supported class
   expect_error(convert_dtm(list(a = vec)))
 })
@@ -101,36 +120,36 @@ test_that("convert_dtm can handle various inputs", {
 # test-lda_core.R, this just tests bad inputs
 
 test_that("format_eta chokes on bad inputs", {
-
+  
   # eta non numeric
   expect_error(format_eta(eta = "WRONG!", k = 3, Nv = 10))
-
+  
   # eta has na values
   expect_error(format_eta(eta = NA, k = 3, Nv = 10))
-
+  
   # eta is zero
   expect_error(format_eta(eta = 0, k = 3, Nv = 10))
-
+  
   # eta doesn't conform to vocabulary or topics
   expect_error(format_eta(eta = numeric(5) + 3, k = 3, Nv = 10))
-
+  
   expect_error(format_eta(eta = matrix(1, nrow = 2, ncol = 10), k = 3, Nv = 10))
-
+  
   # eta is a completely unsupported type
   expect_error(format_eta(eta = list(numeric(10) + 3), k = 3, Nv = 10))
 })
 
 test_that("format_alpha also chokes on bad inputs", {
-
+  
   # alpha non numeric
   expect_error(format_alpha(alpha = "WRONG!", k = 3))
-
+  
   # alpha has na values
   expect_error(format_alpha(alpha = NA, k = 3))
-
+  
   # alpha is zero
   expect_error(format_alpha(alpha = 0, k = 3))
-
+  
   # alpha doesn't conform to vocabulary or topics
   expect_error(format_alpha(alpha = numeric(5) + 3, k = 3))
 })
